==> quant1x-trader-0.1.7.tar.gz: quant1x-trader-0.1.7/setup.py <==
#!/usr/bin/env python
# coding=utf-8
"""The setup script."""
import setuptools
from git import Repo

# from quant1x import __author__

# try:
#     from setuptools import find_packages, setup
# except ImportError:
#     from distutils.core import find_packages, setup

repo = Repo(r'./')
tags = []
for __tag in repo.tags:
    tag = str(__tag)
    tag = tag[1:]
    tags.append(tag)
tags.sort(key=lambda x: tuple(int(v) for v in x.split('.')))
latest = tags[-1]

app__version__ = latest
__author__ = "WangFeng"


def parse_requirements(filename):
    line_iter = (line.strip() for line in open(filename))
    return [line for line in line_iter if line and not line.startswith("#")]


with open("README.rst", encoding="utf-8") as readme_file:
    readme = readme_file.read()

with open("HISTORY.rst", encoding="utf-8") as history_file:
    history = history_file.read()

requirements = parse_requirements("requirements.txt")
test_requirements = requirements

setuptools.setup(
    name="quant1x-trader",
    description="Quant1X程序化自动化交易",
    author_email="wangfengxy@sina.cn",
    url="https://gitee.com/quant1x/trader",
    version=app__version__,
    author=__author__,
    long_description=readme,
    packages=setuptools.find_packages(include=["quant1x.autotrader", "quant1x.autotrader.*"]),
    include_package_data=True,
    install_requires=requirements,
    license="MIT license",
    zip_safe=False,
    keywords="quant1x auto trader",
    entry_points={
        "console_scripts": [
            "quant1x-auto-trader=quant1x.autotrader.__main__:auto_trader",
        ]
    },
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
    ],
    data_files=[
        # ('xtquant', ['xtquant/xtdata.ini', 'xtquant/xtdata.log4cxx']),
    ],
    package_data={
        '': ['*.dll', '*.pyd', '*.ini', '*.log4cxx'],
    },
    test_suite="tests",
    tests_require=test_requirements,
    setup_requires=requirements,
)

==> quant1x-trader-0.2.0.tar.gz: quant1x-trader-0.2.0/setup.py <==
#!/usr/bin/env python
# coding=utf-8
"""The setup script."""
import setuptools
from git import Repo

# from quant1x import __author__

# try:
#     from setuptools import find_packages, setup
# except ImportError:
#     from distutils.core import find_packages, setup

repo = Repo(r'./')
tags = []
for __tag in repo.tags:
    tag = str(__tag)
    tag = tag[1:]
    tags.append(tag)
tags.sort(key=lambda x: tuple(int(v) for v in x.split('.')))
latest = tags[-1]

app__version__ = latest
__author__ = "WangFeng"


def parse_requirements(filename):
    line_iter = (line.strip() for line in open(filename))
    return [line for line in line_iter if line and not line.startswith("#")]


with open("README.rst", encoding="utf-8") as readme_file:
    readme = readme_file.read()

with open("HISTORY.rst", encoding="utf-8") as history_file:
    history = history_file.read()

requirements = parse_requirements("requirements.txt")
test_requirements = requirements

setuptools.setup(
    name="quant1x-trader",
    description="Quant1X程序化自动化交易",
    author_email="wangfengxy@sina.cn",
    url="https://gitee.com/quant1x/trader",
    version=app__version__,
    author=__author__,
    long_description=readme,
    packages=setuptools.find_packages(include=["quant1x.trader", "quant1x.trader.*"]),
    include_package_data=True,
    install_requires=requirements,
    license="MIT license",
    zip_safe=False,
    keywords="quant1x auto trader",
    entry_points={
        "console_scripts": [
            "quant1x-auto-trader=quant1x.trader.auto:auto_trader",
            "quant1x-qmt=quant1x.trader.qmt:main",
        ]
    },
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
    ],
    data_files=[
        # ('xtquant', ['xtquant/xtdata.ini', 'xtquant/xtdata.log4cxx']),
    ],
    package_data={
        '': ['*.dll', '*.pyd', '*.ini', '*.log4cxx'],
    },
    test_suite="tests",
    tests_require=test_requirements,
    setup_requires=requirements,
)
